@@ -5,10 +5,10 @@
 #include <random>
 #include <vector>
 
-#include <tools_for_tests/directories.h>
-#include <tools_for_tests/tiffwrappers.h>
-#include <sopt/logging.h>
-#include <sopt/utilities.h>
+#include "tools_for_tests/directories.h"
+#include "tools_for_tests/tiffwrappers.h"
+#include "sopt/logging.h"
+#include "sopt/utilities.h"
 
 // \min_{x} ||\Psi^\dagger x||_1 \quad \mbox{s.t.} \quad ||y - x||_2 < \epsilon and x \geq 0
 int main(int argc, char const **argv) {
@@ -19,10 +19,6 @@ int main(int argc, char const **argv) {
     exit(0);
   }
 
-  // Initializes and sets logger (if compiled with logging)
-  // See set_level function for levels.
-  sopt::logging::initialize();
-
   // Read input file
   auto const image = sopt::notinstalled::read_standard_tiff(argv[1]);
   sopt::utilities::write_tiff(image, argv[2]);
